@@ -35,5 +35,5 @@ def download_latest(dongle_id):
     last_drive = '--'.join(last_segment.split('--')[:-1])
     cmd = f'aws s3 sync s3://{bucket}/{dongle_id} .  --exclude="*" --include="{last_drive}*"'
     # s3.meta.client.download_file(bucket, last_drive, dongle_id)
-    print(f"Running {cmd}"
+    print(f"Running {cmd}")
     os.system(cmd)
\ No newline at end of file
