@@ -12,7 +12,7 @@ def execute(command: str, filt_cond: str, directory=''):
     '''
     df = get_files_as_pd(directory)
 
-    import ipdb; ipdb.set_trace()
+    # import ipdb; ipdb.set_trace()
 
     target_files = pd.Series(filter(lambda x: filt_cond in x, df.full_path.values))
     target_fcn = lambda x: os.system(eval(command))
