@@ -29,7 +29,7 @@ def write_sftp(name: str, remote: str, ip: int,
             "*.png",
             "*.jpg",
             "*.npy",
-            ".git/",
+            ".git/", 
             "*.pt",
             "wandb/"
         ]
@@ -40,7 +40,7 @@ def write_sftp(name: str, remote: str, ip: int,
         json.dump(new_config, open(sftp_path, 'w'))
 
     else:
-        old_config = json.loads(sftp_path)
+        old_config = json.load(open(sftp_path, 'r'))
         # TODO: update values from new config
         config = {
             **new_config
